==> ruff-0.0.292.tar.gz: ruff-0.0.292/crates/ruff_linter/src/rules/pyupgrade/rules/unicode_kind_prefix.rs <==
use ruff_diagnostics::{AlwaysFixableViolation, Diagnostic, Edit, Fix};
use ruff_macros::{derive_message_formats, violation};
use ruff_python_ast::Expr;
use ruff_text_size::{Ranged, TextRange, TextSize};

use crate::checkers::ast::Checker;
use crate::registry::AsRule;

/// ## What it does
/// Checks for uses of the Unicode kind prefix (`u`) in strings.
///
/// ## Why is this bad?
/// In Python 3, all strings are Unicode by default. The Unicode kind prefix is
/// unnecessary and should be removed to avoid confusion.
///
/// ## Example
/// ```python
/// u"foo"
/// ```
///
/// Use instead:
/// ```python
/// "foo"
/// ```
///
/// ## References
/// - [Python documentation: Unicode HOWTO](https://docs.python.org/3/howto/unicode.html)
#[violation]
pub struct UnicodeKindPrefix;

impl AlwaysFixableViolation for UnicodeKindPrefix {
    #[derive_message_formats]
    fn message(&self) -> String {
        format!("Remove unicode literals from strings")
    }

    fn fix_title(&self) -> String {
        "Remove unicode prefix".to_string()
    }
}

/// UP025
pub(crate) fn unicode_kind_prefix(checker: &mut Checker, expr: &Expr, is_unicode: bool) {
    if is_unicode {
        let mut diagnostic = Diagnostic::new(UnicodeKindPrefix, expr.range());
        if checker.patch(diagnostic.kind.rule()) {
            diagnostic.set_fix(Fix::automatic(Edit::range_deletion(TextRange::at(
                expr.start(),
                TextSize::from(1),
            ))));
        }
        checker.diagnostics.push(diagnostic);
    }
}

==> ruff-0.1.6.tar.gz: ruff-0.1.6/crates/ruff_linter/src/rules/pyupgrade/rules/unicode_kind_prefix.rs <==
use ruff_diagnostics::{AlwaysFixableViolation, Diagnostic, Edit, Fix};
use ruff_macros::{derive_message_formats, violation};

use ruff_python_parser::lexer::LexResult;
use ruff_python_parser::{StringKind, Tok};

use ruff_text_size::{Ranged, TextRange, TextSize};

/// ## What it does
/// Checks for uses of the Unicode kind prefix (`u`) in strings.
///
/// ## Why is this bad?
/// In Python 3, all strings are Unicode by default. The Unicode kind prefix is
/// unnecessary and should be removed to avoid confusion.
///
/// ## Example
/// ```python
/// u"foo"
/// ```
///
/// Use instead:
/// ```python
/// "foo"
/// ```
///
/// ## References
/// - [Python documentation: Unicode HOWTO](https://docs.python.org/3/howto/unicode.html)
#[violation]
pub struct UnicodeKindPrefix;

impl AlwaysFixableViolation for UnicodeKindPrefix {
    #[derive_message_formats]
    fn message(&self) -> String {
        format!("Remove unicode literals from strings")
    }

    fn fix_title(&self) -> String {
        "Remove unicode prefix".to_string()
    }
}

/// UP025
pub(crate) fn unicode_kind_prefix(diagnostics: &mut Vec<Diagnostic>, tokens: &[LexResult]) {
    for (token, range) in tokens.iter().flatten() {
        if let Tok::String {
            kind: StringKind::Unicode,
            ..
        } = token
        {
            let mut diagnostic = Diagnostic::new(UnicodeKindPrefix, *range);
            diagnostic.set_fix(Fix::safe_edit(Edit::range_deletion(TextRange::at(
                range.start(),
                TextSize::from(1),
            ))));
            diagnostics.push(diagnostic);
        }
    }
}
